@@ -4,6 +4,7 @@ import sys
 import collections
 import itertools
 import random
+from dedupe.core import randomPairs
 
 def consoleLabel(deduper): # pragma : no cover
     '''
@@ -113,7 +114,7 @@ def trainingDataLink(data_1, data_2, common_key, training_size=50000) :
 
     return training_pairs        
         
-
+        
 def trainingDataDedupe(data, common_key, training_size=50000) :
     '''
     Construct training data for consumption by the ActiveLearning 
@@ -141,18 +142,28 @@ def trainingDataDedupe(data, common_key, training_size=50000) :
     identified_records = collections.defaultdict(list)
     matched_pairs = set()
     distinct_pairs = set()
-
+    unique_record_ids = set()
+    
+    # a list of record_ids associated with each common_key
     for record_id, record in data.items() :
+        unique_record_ids.add(record_id)
         identified_records[record[common_key]].append(record_id)
 
+    # all combinations of matched_pairs from each common_key group
     for record_ids in identified_records.values() :
         if len(record_ids) > 1 :
             matched_pairs.update(itertools.combinations(sorted(record_ids), 2))
 
-    distinct_pairs.update(itertools.combinations(sorted(data.keys()), 2))
-    distinct_pairs -= matched_pairs
+    # calculate indices using dedupe.core.randomPairs to avoid 
+    # the memory cost of enumerating all possible pairs
+    unique_record_ids = list(unique_record_ids)
+    pair_indices = randomPairs(len(unique_record_ids), training_size)
+    distinct_pairs = set()
+    for i, j in pair_indices:
+        distinct_pairs.add((unique_record_ids[i],
+                            unique_record_ids[j]))
 
-    distinct_pairs = random.sample(distinct_pairs, training_size)
+    distinct_pairs -= matched_pairs
 
     matched_records = [(data[key_1], data[key_2])
                        for key_1, key_2 in matched_pairs]
